﻿using System;
using Microsoft.EntityFrameworkCore;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata;
using SUCOCoreControl.Models;
using SUCOCoreControl.Models.RazorBudget;

namespace SUCOCoreControl.Models.RazorBudget
{
    public partial class SUCODbContext : DbContext
    {
        public SUCODbContext()
        {
        }

        public SUCODbContext(DbContextOptions<SUCODbContext> options)
            : base(options)
        {
        }

        public virtual DbSet<CAICAPEXBudget> CAICAPEXBudget { get; set; }
        public virtual DbSet<CAIOPEXBudget> CAIOPEXBudget { get; set; }
        public virtual DbSet<CAPEXReq> CAPEXReq { get; set; }
        public virtual DbSet<CAPEXWBS> CAPEXWBS { get; set; }
        public virtual DbSet<Company> Company { get; set; }
        public virtual DbSet<GILPGCAPEXBudget> GILPGCAPEXBudget { get; set; }
        public virtual DbSet<GIOPEXBudget> GIOPEXBudget { get; set; }
        public virtual DbSet<Header> Header { get; set; }
        public virtual DbSet<LPGOPEXBudget> LPGOPEXBudget { get; set; }
        public virtual DbSet<OPEXReq> OPEXReq { get; set; }
        public virtual DbSet<OPEXWBS> OPEXWBS { get; set; }
        public virtual DbSet<Period> Period { get; set; }
        public virtual DbSet<Project> Project { get; set; }
        public virtual DbSet<RBCAPEXBudget> RBCAPEXBudget { get; set; }
        public virtual DbSet<RBOPEXBudget> RBOPEXBudget { get; set; }
        public virtual DbSet<RBSBMCAPEXBudget> RBSBMCAPEXBudget { get; set; }
        public virtual DbSet<SubHeader> SubHeader { get; set; }
        public virtual DbSet<ZBCAPEXBudget> ZBCAPEXBudget { get; set; }
        public virtual DbSet<ZBOPEXBudget> ZBOPEXBudget { get; set; }
        public virtual DbSet<ZBSBMCAPEXBudget> ZBSBMCAPEXBudget { get; set; }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            if (!optionsBuilder.IsConfigured)
            {
                optionsBuilder.UseSqlServer("Server=DESKTOP-Q7HKVQ7\\SQLEXPRESS; Database=SUCOCoreControl; Trusted_Connection=True");
            }
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.HasAnnotation("ProductVersion", "2.2.2-servicing-10034");

            modelBuilder.Entity<CAICAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.CAICAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXBudAmount).HasComputedColumnSql("(([OriginalCAPEX]+[IncreaseDecrease])+[CarryOverCAPEX])");

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.CAICAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_CAICAPEXBudget_CAPEXWBSID");
            });

            modelBuilder.Entity<CAIOPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.OPEXWBSID);

                entity.Property(e => e.CAIOPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.OPEXBudAmount).HasComputedColumnSql("((([Q1]+[Q2])+[Q3])+[Q4])");

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.CAIOPEXBudget)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_CAIOPEXBudget_OPEXWBSID");
            });

            modelBuilder.Entity<CAPEXReq>(entity =>
            {
                entity.Property(e => e.CAPEXReqID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Notes).IsUnicode(false);
            });

            modelBuilder.Entity<CAPEXWBS>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSENG)
                    .HasName("KEY_CAPEXWBS_CAPEXWBSENG")
                    .IsUnique();

                entity.Property(e => e.CAPEXWBSID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderID).IsUnicode(false);

                entity.HasOne(d => d.SubHeader)
                    .WithMany(p => p.CAPEXWBS)
                    .HasForeignKey(d => d.SubHeaderID)
                    .HasConstraintName("FK_CAPEXWBS_SubHeaderID");
            });

            modelBuilder.Entity<Company>(entity =>
            {
                entity.Property(e => e.CompanyID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.CompanyARB).IsUnicode(false);

                entity.Property(e => e.CompanyENG).IsUnicode(false);
            });

            modelBuilder.Entity<GILPGCAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.GILPGCAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.GILPGCAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_GILPGCAPEXBudget_CAPEXWBSID");
            });

            modelBuilder.Entity<GIOPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.OPEXWBSID);

                entity.Property(e => e.GIOPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.GIOPEXBudget)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_GIOPEXBudget_OPEXWBSID");
            });

            modelBuilder.Entity<Header>(entity =>
            {
                entity.Property(e => e.HeaderID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectID).IsUnicode(false);

                entity.HasOne(d => d.Project)
                    .WithMany(p => p.Header)
                    .HasForeignKey(d => d.ProjectID)
                    .HasConstraintName("FK_Header_Project");
            });

            modelBuilder.Entity<LPGOPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.OPEXWBSID);

                entity.Property(e => e.LPGOPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.LPGOPEXBudget)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_LPGOPEXBudget_OPEXWBSID");
            });

            modelBuilder.Entity<OPEXReq>(entity =>
            {
                entity.Property(e => e.OPEXReqID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.Notes).IsUnicode(false);

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.OPEXReq)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .HasConstraintName("FK_OPEXReq_OPEXWBSID");
            });

            modelBuilder.Entity<OPEXWBS>(entity =>
            {
                entity.Property(e => e.OPEXWBSID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.ServiceMaterialARB).IsUnicode(false);

                entity.Property(e => e.ServiceMaterialENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderID).IsUnicode(false);

                entity.HasOne(d => d.SubHeader)
                    .WithMany(p => p.OPEXWBS)
                    .HasForeignKey(d => d.SubHeaderID)
                    .HasConstraintName("FK_OPEXWBS_SubHeaderID");
            });

            modelBuilder.Entity<Period>(entity =>
            {
                entity.Property(e => e.PeriodID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.Month).IsUnicode(false);
            });

            modelBuilder.Entity<Project>(entity =>
            {
                entity.Property(e => e.ProjectID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.CompanyID).IsUnicode(false);

                entity.Property(e => e.ProjectARB).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.ProjectType).IsUnicode(false);

                entity.HasOne(d => d.Company)
                    .WithMany(p => p.Project)
                    .HasForeignKey(d => d.CompanyID)
                    .HasConstraintName("FK_Project_Company");
            });

            modelBuilder.Entity<RBCAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.RBCAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.RBCAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_RBCAPEXBudget_CAPEXWBSID");
            });

            modelBuilder.Entity<RBOPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.OPEXWBSID);

                entity.Property(e => e.RBOPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.RBOPEXBudget)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_RBOPEXBudget_OPEXWBSID");
            });

            modelBuilder.Entity<RBSBMCAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.RBSBMCAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.RBSBMCAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_RBSBMCAPEXBudget_CAPEXWBSID");
            });

            modelBuilder.Entity<SubHeader>(entity =>
            {
                entity.Property(e => e.SubHeaderID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.HeaderID).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.Header)
                    .WithMany(p => p.SubHeader)
                    .HasForeignKey(d => d.HeaderID)
                    .HasConstraintName("FK_SubHeader_HeaderID");
            });

            modelBuilder.Entity<ZBCAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.ZBCAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.ZBCAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_ZBCAPEXBudget_CAPEXWBSID");
            });

            modelBuilder.Entity<ZBOPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.OPEXWBSID);

                entity.Property(e => e.ZBOPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.OPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.OPEXWBSID).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.Property(e => e.SubHeaderENG).IsUnicode(false);

                entity.HasOne(d => d.OPEXWBS)
                    .WithMany(p => p.ZBOPEXBudget)
                    .HasForeignKey(d => d.OPEXWBSID)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_ZBOPEXBudget_OPEXWBSID");
            });

            modelBuilder.Entity<ZBSBMCAPEXBudget>(entity =>
            {
                entity.HasIndex(e => e.CAPEXWBSID);

                entity.Property(e => e.ZBSBMCAPEXBudgetID)
                    .IsUnicode(false)
                    .ValueGeneratedNever();

                entity.Property(e => e.BudgetYear).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSENG).IsUnicode(false);

                entity.Property(e => e.CAPEXWBSID).IsUnicode(false);

                entity.Property(e => e.Description).IsUnicode(false);

                entity.Property(e => e.HeaderARB).IsUnicode(false);

                entity.Property(e => e.HeaderENG).IsUnicode(false);

                entity.Property(e => e.ProjectENG).IsUnicode(false);

                entity.Property(e => e.SubHeaderARB).IsUnicode(false);

                entity.HasOne(d => d.CAPEXWBS)
                    .WithMany(p => p.ZBSBMCAPEXBudget)
                    .HasForeignKey(d => d.CAPEXWBSID)
                    .HasConstraintName("FK_ZBSBMCAPEXBudget_CAPEXWBSID");
            });

            
        }
    }
}
