﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using SUCOCoreControl.Models;
using SUCOCoreControl.Services;
using Newtonsoft.Json;
using SUCOCoreControl.Models.RazorBudget;
using SUCOCoreControl.Data;
using Microsoft.Extensions.Logging;

namespace SUCOCoreControl
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddDbContext<ApplicationDbContext>(options =>
                options.UseSqlServer(Configuration.GetConnectionString("DefaultConnection")));

            services.AddIdentity<ApplicationUser, ApplicationRole>()
    .AddEntityFrameworkStores<ApplicationDbContext>()
    .AddDefaultTokenProviders();

            services.AddDbContext<SUCODbContext>(options =>
                options.UseSqlServer(Configuration.GetConnectionString("SUCOConnection"), o => o.MigrationsAssembly("SUCOCoreControl")));

              // Add application services.
            services.AddTransient<IEmailSender, EmailSender>();

            services.AddMvc()
                .AddJsonOptions(options => options.SerializerSettings.NullValueHandling = NullValueHandling.Ignore);
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env, ILoggerFactory loggerFactory)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
                app.UseBrowserLink();
                app.UseDatabaseErrorPage();
            }
            else
            {
                app.UseExceptionHandler("/Home/Error");
            }

            Syncfusion.Licensing.SyncfusionLicenseProvider.RegisterLicense("ODk4OThAMzEzNzJlMzEyZTMwZ0h5MXE2d29YNGlWNndEWEI3QUtzZFN4VDhXRmFFaFZSdmh3MHNua1FUYz0=;ODk4OTlAMzEzNzJlMzEyZTMwb01hdGVXd1NlektNZ1NDTlNINmgyMFdiclhsbjczSjNJUGFRQjJRMFZLbz0=;ODk5MDBAMzEzNzJlMzEyZTMwUGVyK01FQVRmdFpUdm1qY1ZqWU9HK0JaajdZT2pwa2ZwYUVkMnZvY0c1TT0=");

            app.UseStaticFiles();

            app.UseAuthentication();

            app.UseMvc(routes =>
            {
                routes.MapRoute(
                    name: "default",
                    template: "{controller=Home}/{action=StartPage}/{id?}");
            });
        }
    }
}
